@@ -56,7 +56,7 @@ macro_rules! command_list {
     frequency   Show frequency tables
     generate*   Generate test data by profiling a CSV
     headers     Show header names
-    help        Show this usage message.
+    help        Show this usage message
     index       Create CSV index for faster access
     input       Read CSV data with special quoting rules
     join        Join CSV files
@@ -64,6 +64,7 @@ macro_rules! command_list {
     lua*        Execute Lua script on CSV data
     partition   Partition CSV data based on a column value
     pseudo      Pseudonymise the values of a column
+    py*         Evaluate a Python expression on CSV data
     sample      Randomly sample CSV data
     rename      Rename the columns of CSV data efficiently
     replace     Replace patterns in CSV data
@@ -79,6 +80,8 @@ macro_rules! command_list {
     transpose   Transpose rows/columns of CSV data
 
     * optional feature
+
+    sponsored by datHere - Data Infrastructure Engineering
 "
     };
 }
@@ -301,6 +304,8 @@ enum Command {
     Lua,
     Partition,
     Pseudo,
+    #[cfg(feature = "python")]
+    Py,
     Rename,
     Replace,
     Reverse,
@@ -359,6 +364,8 @@ impl Command {
             Command::Lua => cmd::lua::run(argv),
             Command::Partition => cmd::partition::run(argv),
             Command::Pseudo => cmd::pseudo::run(argv),
+            #[cfg(feature = "python")]
+            Command::Py => cmd::python::run(argv),
             Command::Rename => cmd::rename::run(argv),
             Command::Replace => cmd::replace::run(argv),
             Command::Reverse => cmd::reverse::run(argv),
