@@ -1,6 +1,8 @@
 use std::env;
 use std::fmt;
 use std::fs;
+use std::fs::File;
+use std::io::Write;
 use std::io::{self, Read};
 use std::path::{Path, PathBuf};
 use std::process;
@@ -35,7 +37,6 @@ impl Workdir {
             .join(QSV_INTEGRATION_TEST_DIR)
             .join(name)
             .join(&format!("test-{}", id));
-        // println!("{:?}", dir);
         if let Err(err) = create_dir_all(&dir) {
             panic!("Could not create '{:?}': {}", dir, err);
         }
@@ -75,6 +76,14 @@ impl Workdir {
         self.run(&mut cmd);
     }
 
+    pub fn create_from_string(&self, name: &str, data: &str) {
+        let filename = &self.path(name);
+        println!("{:?}", filename);
+        let mut file = File::create(filename).unwrap();
+        file.write_all(data.as_bytes()).unwrap();
+        file.flush().unwrap();
+    }
+
     pub fn read_stdout<T: Csv>(&self, cmd: &mut process::Command) -> T {
         let stdout: String = self.stdout(cmd);
         let mut rdr = csv::ReaderBuilder::new()
